Pulsante 'Inserisci immagine'

Pulsante 'Inserisci immagine' | TOC

Il pulsante 'inserisci immagine' apre la finestra mostrata qui sotto.
Si inserisce semplicemente l'url dell'immagine che si vuole collegare e una descrizione di quell'immagine, che sarà mostrato come testo alternativo dell'immagine sulla pagina.
Descrizione dei parametri:

URL immagine | URL/indirizzo dell'immagine.
Descrizione dell'immagine | Descrizione alternativa del contenuto dell'immagine.
Dimensioni | Larghezza/Altezza dell'immagine.
Allineamento | Allineamento dell'immagine, utile quando si inserisce del testo attorno all'immagine.
Bordo | Spessore del bordo.
Spazio verticale | Spazio verticale, utile quando si inserisce del testo attorno all'immagine.
Spazio orizzontale | Spazio orizzontale, utile quando si inserisce del testo attorno all'immagine.

Vai a: Tavola dei contenuti | Su